# ===========================================================================
#
# column.py
#
# Jensen wake 6 Turbines in column
# CBP 02-12-21
# Status: Release
#
# ===========================================================================


import matplotlib.pyplot as plt
import floris.tools as wfct


fi = wfct.floris_interface.FlorisInterface("./jsons/jensen_6InLine.json")

# Calculate wake
fi.calculate_wake()

cts = fi.get_turbine_ct();
print(" ----------------- ")
for i in range(len(cts)):
    print("Turbine %d Ct's = %.2e    ( = %.4f )" % (i,cts[i],cts[i]))
    
# get individual turbine power output
powers = fi.get_turbine_power()
print(" ----------------- ")
for i in range(len(powers)):
    print("Turbine %d power = %.2e    ( = %.1f )" % (i,powers[i],powers[i]))
    
# get total power    
power = fi.get_farm_power()

print(" ----------------- ")
print("Total Power = %.2e   ( = %.1f )" % (power , power))
print(" ----------------- ")

# Get horizontal plane at default height (hub-height)
hor_plane = fi.get_hor_plane()

      
# Plot and show
fig, ax = plt.subplots()
wfct.visualization.visualize_cut_plane(hor_plane, ax=ax)
plt.show()
