# ===========================================================================
#
# yaw2.py
#
# 2 Turbines Manual change yaw angles
# CBP 02-12-21
# Status: Release
#
# ===========================================================================

import os

import numpy as np
import matplotlib.pyplot as plt

import floris.tools as wfct
import floris.tools.visualization as vis


print("Running FLORIS with no yaw...")
# Instantiate the FLORIS object
file_dir = os.path.dirname(os.path.abspath(__file__))
fi = wfct.floris_interface.FlorisInterface(
    os.path.join(file_dir, "./jsons/example_input.json")
)

# Set turbine locations to 3 turbines in a row
D = fi.floris.farm.turbines[0].rotor_diameter
layout_x = [0, 7 * D]
layout_y = [0, 0]
fi.reinitialize_flow_field(layout_array=(layout_x, layout_y))
fi.calculate_wake()

# Initial power output
power_initial = fi.get_farm_power()

# =============================================================================
print("Plotting the FLORIS flowfield...")
# =============================================================================

# Initialize the horizontal cut
hor_plane = fi.get_hor_plane(x_resolution=400, y_resolution=100)

# Plot and show
fig, ax = plt.subplots()
wfct.visualization.visualize_cut_plane(hor_plane, ax=ax)
ax.set_title("Baseline Case for U = 8 m/s, Wind Direction = 270$^\\circ$")

# Specify yaw angles
yaw_angles = [0.0,0.0]

print("==========================================")
print("yaw angles = ")
for i in range(len(yaw_angles)):
    print("Turbine ", i, "=", yaw_angles[i], " deg")

# Assign yaw angles to turbines and calculate wake
fi.calculate_wake(yaw_angles=yaw_angles)
power_opt = fi.get_farm_power()

powers = fi.get_turbine_power()
print(" ----------------- ")
for i in range(len(yaw_angles)):
    print("Turbine %d power = %.2e    ( = %.1f )" % (i,powers[i],powers[i]))

print(" ----------------- ")
print("Init Total Power = %.2e   ( = %.1f )" % (power_initial, power_initial))
print(" ----------------- ")

print(" ----------------- ")
print("Yaw Steer Power = %.2e   ( = %.1f )" % (power_opt, power_opt))
print(" ----------------- ")


print("==========================================")
print(
    "Total Power Gain = %.1f%%" % (100.0 * (power_opt - power_initial) / power_initial)
)
print("==========================================")
# =============================================================================
print("Plotting the FLORIS flowfield with yaw...")
# =============================================================================

# Initialize the horizontal cut
hor_plane = fi.get_hor_plane(x_resolution=400, y_resolution=100)

# Plot and show
fig, ax = plt.subplots()
wfct.visualization.visualize_cut_plane(hor_plane, ax=ax)
ax.set_title("Wake Steering for U = 8 m/s, Wind Direction = 270$^\\circ$")
plt.show()
